.bfw { font-size: 14px; float: left; }
.bfw * { box-sizing: border-box; }
.bfw .title { float: left; width: 220px; font-size: 1.1em; color: #888; font-weight: bold; text-transform: capitalize; }
.bfw input.item-filter { display:block; width: 200px; font-size: 1.5em; height: 40px; padding: 0 10px; background: #eee; border-radius: 0; margin-bottom: 0; }
.bfw .item-list { overflow: auto; float: left; width: 200px; height: 185px; font-size: 1.5em; border: 1px solid #ccc; }
.bfw .selected-items { position: relative; top: -40px; height: 225px;}
.bfw .item-list { float: left; font-size: 1.5em; margin-right: 20px;}
.bfw .item-list .item { display: block; padding: 5px 10px; border-bottom: 1px solid #ddd; cursor: pointer; }
.bfw .item-list .item.selected { display: none; }
.bfw .item-list.available-items .item:active { background: lightgreen; }
.bfw .item-list .glyphicon { float: right; font-size: .9em; line-height: 1.5em; }
.bfw .action-icon { float: right; border-radius: 30px; display: inline-block; width: 20px; height: 20px; color: white; text-align: center; }
.bfw .action-icon-plus { color: lightgreen; }
.bfw .action-icon-minus { color: pink; }
.bfw .item-list.selected-items { height: auto; overflow: visible; }
.bfw .item-list.selected-items .item:active { background: pink; color: white; }
.bf-toast { position: fixed; z-index:10000; top: 5%; left: 45%; text-align: center; background: rgba(0,0,0,.8); border: 1px solid #888; color: white; padding: 1em; border-radius: 3px; display: none; }